<?php return array(
    'root' => array(
        'name' => 'icinga/icinga-php-library',
        'pretty_version' => 'dev-main',
        'version' => 'dev-main',
        'reference' => '435e443a4122da64f92baaa054d65c36bebab77f',
        'type' => 'project',
        'install_path' => __DIR__ . '/../../',
        'aliases' => array(),
        'dev' => true,
    ),
    'versions' => array(
        'brick/math' => array(
            'pretty_version' => '0.9.3',
            'version' => '0.9.3.0',
            'reference' => 'ca57d18f028f84f777b2168cd1911b0dee2343ae',
            'type' => 'library',
            'install_path' => __DIR__ . '/../brick/math',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'doctrine/collections' => array(
            'pretty_version' => '1.8.0',
            'version' => '1.8.0.0',
            'reference' => '2b44dd4cbca8b5744327de78bafef5945c7e7b5e',
            'type' => 'library',
            'install_path' => __DIR__ . '/../doctrine/collections',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'doctrine/deprecations' => array(
            'pretty_version' => 'v1.1.1',
            'version' => '1.1.1.0',
            'reference' => '612a3ee5ab0d5dd97b7cf3874a6efe24325efac3',
            'type' => 'library',
            'install_path' => __DIR__ . '/../doctrine/deprecations',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'dragonmantank/cron-expression' => array(
            'pretty_version' => 'v3.3.3',
            'version' => '3.3.3.0',
            'reference' => 'adfb1f505deb6384dc8b39804c5065dd3c8c8c0a',
            'type' => 'library',
            'install_path' => __DIR__ . '/../dragonmantank/cron-expression',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'evenement/evenement' => array(
            'pretty_version' => 'v3.0.2',
            'version' => '3.0.2.0',
            'reference' => '0a16b0d71ab13284339abb99d9d2bd813640efbc',
            'type' => 'library',
            'install_path' => __DIR__ . '/../evenement/evenement',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'fortawesome/font-awesome' => array(
            'pretty_version' => '6.4.2',
            'version' => '6.4.2.0',
            'reference' => 'f0c25837a3fe0e03783b939559e088abcbfb3c4b',
            'type' => 'library',
            'install_path' => __DIR__ . '/../fortawesome/font-awesome',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'guzzlehttp/psr7' => array(
            'pretty_version' => '2.6.1',
            'version' => '2.6.1.0',
            'reference' => 'be45764272e8873c72dbe3d2edcfdfcc3bc9f727',
            'type' => 'library',
            'install_path' => __DIR__ . '/../guzzlehttp/psr7',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'icinga/icinga-php-library' => array(
            'pretty_version' => 'dev-main',
            'version' => 'dev-main',
            'reference' => '435e443a4122da64f92baaa054d65c36bebab77f',
            'type' => 'project',
            'install_path' => __DIR__ . '/../../',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'ipl/html' => array(
            'pretty_version' => 'v0.8.0',
            'version' => '0.8.0.0',
            'reference' => 'ad522bfd34521d4deb147e99e19a6dbf22bc15d1',
            'type' => 'library',
            'install_path' => __DIR__ . '/../ipl/html',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'ipl/i18n' => array(
            'pretty_version' => 'v0.2.1',
            'version' => '0.2.1.0',
            'reference' => '9803bdd30be1780736a9e0102c41caaf61bcf709',
            'type' => 'library',
            'install_path' => __DIR__ . '/../ipl/i18n',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'ipl/orm' => array(
            'pretty_version' => 'v0.6.0',
            'version' => '0.6.0.0',
            'reference' => 'ed6d9374c9d72a5dd0bc15ec725f7926bf1853e0',
            'type' => 'library',
            'install_path' => __DIR__ . '/../ipl/orm',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'ipl/scheduler' => array(
            'pretty_version' => 'v0.1.2',
            'version' => '0.1.2.0',
            'reference' => '6119afdea07b1390bd728e350e0d80b26ec8d6ba',
            'type' => 'library',
            'install_path' => __DIR__ . '/../ipl/scheduler',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'ipl/sql' => array(
            'pretty_version' => 'v0.7.0',
            'version' => '0.7.0.0',
            'reference' => 'abcecf3987cec49c57f63f5a51383806408124db',
            'type' => 'library',
            'install_path' => __DIR__ . '/../ipl/sql',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'ipl/stdlib' => array(
            'pretty_version' => 'v0.13.0',
            'version' => '0.13.0.0',
            'reference' => '1150af1155df4fddbd9d8ea3c06e9e5258fdb034',
            'type' => 'library',
            'install_path' => __DIR__ . '/../ipl/stdlib',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'ipl/validator' => array(
            'pretty_version' => 'v0.5.0',
            'version' => '0.5.0.0',
            'reference' => 'a601fae0ed330e63cea50e4a2a6659ca1ad97bde',
            'type' => 'library',
            'install_path' => __DIR__ . '/../ipl/validator',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'ipl/web' => array(
            'pretty_version' => 'v0.9.0',
            'version' => '0.9.0.0',
            'reference' => '656c1dc51b053f48ec885dc0026810ab53fcd8db',
            'type' => 'library',
            'install_path' => __DIR__ . '/../ipl/web',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'mtdowling/cron-expression' => array(
            'dev_requirement' => false,
            'replaced' => array(
                0 => '^1.0',
            ),
        ),
        'psr/http-factory' => array(
            'pretty_version' => '1.0.2',
            'version' => '1.0.2.0',
            'reference' => 'e616d01114759c4c489f93b099585439f795fe35',
            'type' => 'library',
            'install_path' => __DIR__ . '/../psr/http-factory',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'psr/http-factory-implementation' => array(
            'dev_requirement' => false,
            'provided' => array(
                0 => '1.0',
            ),
        ),
        'psr/http-message' => array(
            'pretty_version' => '1.1',
            'version' => '1.1.0.0',
            'reference' => 'cb6ce4845ce34a8ad9e68117c10ee90a29919eba',
            'type' => 'library',
            'install_path' => __DIR__ . '/../psr/http-message',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'psr/http-message-implementation' => array(
            'dev_requirement' => false,
            'provided' => array(
                0 => '1.0',
            ),
        ),
        'psr/log' => array(
            'pretty_version' => '1.1.4',
            'version' => '1.1.4.0',
            'reference' => 'd49695b909c3b7628b6289db5479a1c204601f11',
            'type' => 'library',
            'install_path' => __DIR__ . '/../psr/log',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'ralouphie/getallheaders' => array(
            'pretty_version' => '3.0.3',
            'version' => '3.0.3.0',
            'reference' => '120b605dfeb996808c31b6477290a714d356e822',
            'type' => 'library',
            'install_path' => __DIR__ . '/../ralouphie/getallheaders',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'ramsey/collection' => array(
            'pretty_version' => '1.1.4',
            'version' => '1.1.4.0',
            'reference' => 'ab2237657ad99667a5143e32ba2683c8029563d4',
            'type' => 'library',
            'install_path' => __DIR__ . '/../ramsey/collection',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'ramsey/uuid' => array(
            'pretty_version' => '4.2.3',
            'version' => '4.2.3.0',
            'reference' => 'fc9bb7fb5388691fd7373cd44dcb4d63bbcf24df',
            'type' => 'library',
            'install_path' => __DIR__ . '/../ramsey/uuid',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'react/event-loop' => array(
            'pretty_version' => 'v1.4.0',
            'version' => '1.4.0.0',
            'reference' => '6e7e587714fff7a83dcc7025aee42ab3b265ae05',
            'type' => 'library',
            'install_path' => __DIR__ . '/../react/event-loop',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'react/promise' => array(
            'pretty_version' => 'v2.10.0',
            'version' => '2.10.0.0',
            'reference' => 'f913fb8cceba1e6644b7b90c4bfb678ed8a3ef38',
            'type' => 'library',
            'install_path' => __DIR__ . '/../react/promise',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'rhumsaa/uuid' => array(
            'dev_requirement' => false,
            'replaced' => array(
                0 => '4.2.3',
            ),
        ),
        'simshaun/recurr' => array(
            'pretty_version' => 'v5.0.1',
            'version' => '5.0.1.0',
            'reference' => '6887b7bd7075de97c8c69835e0939ff68d23c47e',
            'type' => 'library',
            'install_path' => __DIR__ . '/../simshaun/recurr',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'symfony/polyfill-ctype' => array(
            'pretty_version' => 'v1.28.0',
            'version' => '1.28.0.0',
            'reference' => 'ea208ce43cbb04af6867b4fdddb1bdbf84cc28cb',
            'type' => 'library',
            'install_path' => __DIR__ . '/../symfony/polyfill-ctype',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'symfony/polyfill-php80' => array(
            'pretty_version' => 'v1.28.0',
            'version' => '1.28.0.0',
            'reference' => '6caa57379c4aec19c0a12a38b59b26487dcfe4b5',
            'type' => 'library',
            'install_path' => __DIR__ . '/../symfony/polyfill-php80',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'webmozart/assert' => array(
            'pretty_version' => '1.11.0',
            'version' => '1.11.0.0',
            'reference' => '11cb2199493b2f8a3b53e7f19068fc6aac760991',
            'type' => 'library',
            'install_path' => __DIR__ . '/../webmozart/assert',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'wikimedia/less.php' => array(
            'pretty_version' => 'v3.2.1',
            'version' => '3.2.1.0',
            'reference' => '0d5b30ba792bdbf8991a646fc9c30561b38a5559',
            'type' => 'library',
            'install_path' => __DIR__ . '/../wikimedia/less.php',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
    ),
);
